<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ActionsShortcutsModel</name>
    <message>
        <location filename="../shortcuts_management/actions_shortcuts_model.cpp" line="73"/>
        <source>None</source>
        <translation>Rien</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <location filename="bookmarks_dialog.cpp" line="75"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="107"/>
        <location filename="bookmarks_dialog.cpp" line="124"/>
        <source>Loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="85"/>
        <source>Click on any image to go to the bookmark</source>
        <translation>Cliquez sur une image pour aller au marque-page</translation>
    </message>
    <message>
        <location filename="bookmarks_dialog.cpp" line="25"/>
        <source>Lastest Page</source>
        <translation>Aller à la dernière page</translation>
    </message>
</context>
<context>
    <name>EditShortcutsDialog</name>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>Shortcut in use</source>
        <translation>Raccourci en cours d&apos;utilisation</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="23"/>
        <source>Restore defaults</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="71"/>
        <source>Shortcuts settings</source>
        <translation>Paramètres de raccourcis</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="96"/>
        <source>The shortcut &quot;%1&quot; is already assigned to other function</source>
        <translation>Le raccourci &quot;%1&quot; est déjà affecté à une autre fonction</translation>
    </message>
    <message>
        <location filename="../shortcuts_management/edit_shortcuts_dialog.cpp" line="24"/>
        <source>To change a shortcut, double click in the key combination and type the new keys.</source>
        <translation>Pour modifier un raccourci, double-cliquez sur la combinaison de touches et tapez les nouvelles clés.</translation>
    </message>
</context>
<context>
    <name>FileComic</name>
    <message>
        <location filename="../common/comic.cpp" line="568"/>
        <source>Format not supported</source>
        <translation>Format non supporté</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="562"/>
        <source>7z not found</source>
        <translation>7z introuvable</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="461"/>
        <source>Unknown error opening the file</source>
        <translation>Erreur inconnue lors de l&apos;ouverture du fichier</translation>
    </message>
    <message>
        <location filename="../common/comic.cpp" line="454"/>
        <source>CRC error on page (%1): some of the pages will not be displayed correctly</source>
        <translation>Erreur CRC sur la page (%1): certaines pages ne s&apos;afficheront pas correctement</translation>
    </message>
</context>
<context>
    <name>GoToDialog</name>
    <message>
        <location filename="goto_dialog.cpp" line="23"/>
        <source>Go To</source>
        <translation>Aller à</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="53"/>
        <source>Go to...</source>
        <translation>Aller à...</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="39"/>
        <location filename="goto_dialog.cpp" line="71"/>
        <source>Total pages : </source>
        <translation>Nombre de pages :</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="25"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="goto_dialog.cpp" line="15"/>
        <source>Page : </source>
        <translation>Page :</translation>
    </message>
</context>
<context>
    <name>GoToFlowToolBar</name>
    <message>
        <location filename="goto_flow_toolbar.cpp" line="38"/>
        <source>Page : </source>
        <translation>Page : </translation>
    </message>
</context>
<context>
    <name>HelpAboutDialog</name>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="30"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="33"/>
        <source>System info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../custom_widgets/help_about_dialog.cpp" line="27"/>
        <source>About</source>
        <translation>A propos</translation>
    </message>
</context>
<context>
    <name>LogWindow</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="14"/>
        <source>Log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="22"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="39"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="56"/>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="73"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="90"/>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.ui" line="136"/>
        <source>&amp;Auto scroll</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindowViewer</name>
    <message>
        <source>Go</source>
        <translation type="vanished">Aller</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="vanished">Editer</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Fichier</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Aide</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Sauvegarder</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Vue</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="vanished">&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation type="vanished">&amp;Suivant</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">&amp;Ouvrir</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
    <message>
        <source>Open Comic</source>
        <translation type="vanished">Ouvrir la bande dessinée</translation>
    </message>
    <message>
        <source>Go To</source>
        <translation type="vanished">Aller à</translation>
    </message>
    <message>
        <source>Zoom+</source>
        <translation type="vanished">Zoom+</translation>
    </message>
    <message>
        <source>Zoom-</source>
        <translation type="vanished">Zoom-</translation>
    </message>
    <message>
        <source>Open image folder</source>
        <translation type="vanished">Ouvrir un dossier d&apos;images</translation>
    </message>
    <message>
        <source>Size down magnifying glass</source>
        <translation type="vanished">Réduire la taille de la loupe</translation>
    </message>
    <message>
        <source>Zoom out magnifying glass</source>
        <translation type="vanished">Dézoomer</translation>
    </message>
    <message>
        <source>Open latest comic</source>
        <translation type="vanished">Ouvrir la dernière bande dessinée</translation>
    </message>
    <message>
        <source>Autoscroll up</source>
        <translation type="vanished">Défilement automatique vers le haut</translation>
    </message>
    <message>
        <source>Set bookmark</source>
        <translation type="vanished">Placer un marque-page</translation>
    </message>
    <message>
        <source>page_%1.jpg</source>
        <translation type="vanished">page_%1.jpg</translation>
    </message>
    <message>
        <source>Autoscroll forward, vertical first</source>
        <translation type="vanished">Défilement automatique en avant, vertical</translation>
    </message>
    <message>
        <source>Switch to double page mode</source>
        <translation type="vanished">Passer en mode double page</translation>
    </message>
    <message>
        <source>Save current page</source>
        <translation type="vanished">Sauvegarder la page actuelle</translation>
    </message>
    <message>
        <source>Size up magnifying glass</source>
        <translation type="vanished">Augmenter la taille de la loupe</translation>
    </message>
    <message>
        <source>Double page mode</source>
        <translation type="vanished">Mode double page</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation type="vanished">Monter</translation>
    </message>
    <message>
        <source>Switch Magnifying glass</source>
        <translation type="vanished">Utiliser la loupe</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="vanished">Ouvrir un dossier</translation>
    </message>
    <message>
        <source>Comics</source>
        <translation type="vanished">Bandes dessinées</translation>
    </message>
    <message>
        <source>Fit Height</source>
        <translation type="vanished">Ajuster la hauteur</translation>
    </message>
    <message>
        <source>Autoscroll backward, vertical first</source>
        <translation type="vanished">Défilement automatique en arrière, verticak</translation>
    </message>
    <message>
        <source>Comic files</source>
        <translation type="vanished">Bande dessinée</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="vanished">Pas maintenant</translation>
    </message>
    <message>
        <source>Go to the first page</source>
        <translation type="vanished">Aller à la première page</translation>
    </message>
    <message>
        <source>Go to previous page</source>
        <translation type="vanished">Aller à la page précédente</translation>
    </message>
    <message>
        <source>Window</source>
        <translation type="vanished">Fenêtre</translation>
    </message>
    <message>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="vanished">Ouvrir la dernière bande dessinée ouverte lors de la session de lecture précédente</translation>
    </message>
    <message>
        <source>Open a comic</source>
        <translation type="vanished">Ouvrir une bande dessinée</translation>
    </message>
    <message>
        <source>Image files (*.jpg)</source>
        <translation type="vanished">Image(*.jpg)</translation>
    </message>
    <message>
        <source>Next Comic</source>
        <translation type="vanished">Bande dessinée suivante</translation>
    </message>
    <message>
        <source>Fit Width</source>
        <translation type="vanished">Ajuster la largeur</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="vanished">Options</translation>
    </message>
    <message>
        <source>Show Info</source>
        <translation type="vanished">Voir les infos</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Ouvirir le dossier</translation>
    </message>
    <message>
        <source>Go to page ...</source>
        <translation type="vanished">Aller à la page ...</translation>
    </message>
    <message>
        <source>Magnifiying glass</source>
        <translation type="vanished">Loupe</translation>
    </message>
    <message>
        <source>Fit image to width</source>
        <translation type="vanished">Ajuster l&apos;image à la largeur</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode</source>
        <translation type="vanished">Basculer en mode plein écran</translation>
    </message>
    <message>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="vanished">Basculer entre adapter à la largeur et adapter à la hauteur</translation>
    </message>
    <message>
        <source>Move right</source>
        <translation type="vanished">Déplacer à droite</translation>
    </message>
    <message>
        <source>Zoom in magnifying glass</source>
        <translation type="vanished">Zoomer</translation>
    </message>
    <message>
        <source>Open recent</source>
        <translation type="vanished">Ouvrir récent</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lecture</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation type="vanished">&amp;Précédent</translation>
    </message>
    <message>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="vanished">Défilement automatique en avant, horizontal</translation>
    </message>
    <message>
        <source>Go to next page</source>
        <translation type="vanished">Aller à la page suivante</translation>
    </message>
    <message>
        <source>Show keyboard shortcuts</source>
        <translation type="vanished">Voir les raccourcis</translation>
    </message>
    <message>
        <source>Double page manga mode</source>
        <translation type="vanished">Mode manga en double page</translation>
    </message>
    <message>
        <source>There is a new version available</source>
        <translation type="vanished">Une nouvelle version est disponible</translation>
    </message>
    <message>
        <source>Autoscroll down</source>
        <translation type="vanished">Défilement automatique vers le bas</translation>
    </message>
    <message>
        <source>Open next comic</source>
        <translation type="vanished">Ouvrir la bande dessinée suivante</translation>
    </message>
    <message>
        <source>Remind me in 14 days</source>
        <translation type="vanished">Rappelez-moi dans 14 jours</translation>
    </message>
    <message>
        <source>Fit to page</source>
        <translation type="vanished">Ajuster à la page</translation>
    </message>
    <message>
        <source>Show bookmarks</source>
        <translation type="vanished">Voir les marque-pages</translation>
    </message>
    <message>
        <source>Open previous comic</source>
        <translation type="vanished">Ouvrir la bande dessiné précédente</translation>
    </message>
    <message>
        <source>Rotate image to the left</source>
        <translation type="vanished">Rotation à gauche</translation>
    </message>
    <message>
        <source>Fit image to height</source>
        <translation type="vanished">Ajuster l&apos;image à la hauteur</translation>
    </message>
    <message>
        <source>Reset zoom</source>
        <translation type="vanished">Réinitialiser le zoom</translation>
    </message>
    <message>
        <source>Show the bookmarks of the current comic</source>
        <translation type="vanished">Voir les marque-pages de cette bande dessinée</translation>
    </message>
    <message>
        <source>Show Dictionary</source>
        <translation type="vanished">Dictionnaire</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation type="vanished">Descendre</translation>
    </message>
    <message>
        <source>Move left</source>
        <translation type="vanished">Déplacer à gauche</translation>
    </message>
    <message>
        <source>Reverse reading order in double page mode</source>
        <translation type="vanished">Ordre de lecture inversée en mode double page</translation>
    </message>
    <message>
        <source>YACReader options</source>
        <translation type="vanished">Options de YACReader</translation>
    </message>
    <message>
        <source>Clear open recent list</source>
        <translation type="vanished">Vider la liste d&apos;ouverture récente</translation>
    </message>
    <message>
        <source>Help, About YACReader</source>
        <translation type="vanished">Aide, à propos de YACReader</translation>
    </message>
    <message>
        <source>Show go to flow</source>
        <translation type="vanished">Afficher le flux</translation>
    </message>
    <message>
        <source>Previous Comic</source>
        <translation type="vanished">Bande dessinée précédente</translation>
    </message>
    <message>
        <source>Show full size</source>
        <translation type="vanished">Plein écran</translation>
    </message>
    <message>
        <source>Hide/show toolbar</source>
        <translation type="vanished">Masquer / afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation type="vanished">Loupe</translation>
    </message>
    <message>
        <source>Edit shortcuts</source>
        <translation type="vanished">Modifier les raccourcis</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Général</translation>
    </message>
    <message>
        <source>Set a bookmark on the current page</source>
        <translation type="vanished">Placer un marque-page sur la page actuelle</translation>
    </message>
    <message>
        <source>Page adjustement</source>
        <translation type="vanished">Ajustement de la page</translation>
    </message>
    <message>
        <source>Show zoom slider</source>
        <translation type="vanished">Afficher le curseur de zoom</translation>
    </message>
    <message>
        <source>Go to the last page</source>
        <translation type="vanished">Aller à la dernière page</translation>
    </message>
    <message>
        <source>Do you want to download the new version?</source>
        <translation type="vanished">Voulez-vous télécharger la nouvelle version?</translation>
    </message>
    <message>
        <source>Rotate image to the right</source>
        <translation type="vanished">Rotation à droite</translation>
    </message>
    <message>
        <source>Always on top</source>
        <translation type="vanished">Toujours au dessus</translation>
    </message>
    <message>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="vanished">Défilement automatique en arrière horizontal</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="options_dialog.cpp" line="145"/>
        <source>Gamma</source>
        <translation>Gamma</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="149"/>
        <source>Reset</source>
        <translation>Remise à zéro</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="34"/>
        <source>My comics path</source>
        <translation>Chemin de mes bandes dessinées</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="193"/>
        <source>Image adjustment</source>
        <translation>Ajustement de l&apos;image</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="43"/>
        <source>&quot;Go to flow&quot; size</source>
        <translation>Taille du flux</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="64"/>
        <source>Choose</source>
        <translation>Choisir</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="154"/>
        <source>Image options</source>
        <translation>Option de l&apos;image</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="144"/>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="208"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="215"/>
        <source>Comics directory</source>
        <translation>Répertoire des bandes dessinées</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="99"/>
        <source>Quick Navigation Mode</source>
        <translation>Mode navigation rapide</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="61"/>
        <source>Background color</source>
        <translation>Couleur d&apos;arrière plan</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="71"/>
        <source>Scroll behaviour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="74"/>
        <source>Disable scroll animations and smooth scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="75"/>
        <source>Do not turn page using scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="76"/>
        <source>Use single scroll step to turn page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="100"/>
        <source>Disable mouse over activation</source>
        <translation>Désactiver la souris sur l&apos;activation</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="192"/>
        <source>Page Flow</source>
        <translation>Flux des pages</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="191"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="143"/>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="199"/>
        <source>Restart is needed</source>
        <translation>Redémarrage nécessaire</translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="158"/>
        <source>Fit options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="160"/>
        <source>Enlarge images to fit width/height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="171"/>
        <source>Double Page options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="options_dialog.cpp" line="173"/>
        <source>Show covers as single page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>7z lib not found</source>
        <translation>lib 7z introuvable</translation>
    </message>
    <message>
        <location filename="../common/exit_check.cpp" line="13"/>
        <source>unable to load 7z lib from ./utils</source>
        <translation>impossible de charger 7z depuis ./utils</translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="41"/>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="43"/>
        <source>Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="45"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="47"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="49"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogLevel.cpp" line="51"/>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::LogWindowModel</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="141"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="143"/>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindowModel.cpp" line="145"/>
        <source>Message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QsLogging::Window</name>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="176"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="236"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../third_party/QsLog/QsLogWindow.cpp" line="237"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsDialog</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
    <message>
        <source>YACReader keyboard shortcuts</source>
        <translation type="vanished">Raccourcis clavier de YACReader</translation>
    </message>
    <message>
        <source>Keyboard Shortcuts</source>
        <translation type="vanished">Raccourcis clavier</translation>
    </message>
</context>
<context>
    <name>Viewer</name>
    <message>
        <location filename="viewer.cpp" line="946"/>
        <source>Page not available!</source>
        <translation>Page non disponible !</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="51"/>
        <location filename="viewer.cpp" line="924"/>
        <source>Press &apos;O&apos; to open comic.</source>
        <translation>Appuyez sur &quot;O&quot; pour ouvrir une bande dessinée.</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="240"/>
        <source>Error opening comic</source>
        <translation>Erreur d&apos;ouverture de la bande dessinée</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1128"/>
        <source>Cover!</source>
        <translation>Couverture!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="246"/>
        <source>CRC Error</source>
        <translation>Erreur CRC</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Comic not found</source>
        <translation>Bande dessinée introuvable</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="234"/>
        <source>Not found</source>
        <translation>Introuvable</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="1142"/>
        <source>Last page!</source>
        <translation>Dernière page!</translation>
    </message>
    <message>
        <location filename="viewer.cpp" line="936"/>
        <source>Loading...please wait!</source>
        <translation>Chargement... Patientez</translation>
    </message>
</context>
<context>
    <name>YACReader::MainWindowViewer</name>
    <message>
        <location filename="main_window_viewer.cpp" line="183"/>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Ouvrir</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="185"/>
        <source>Open a comic</source>
        <translation type="unfinished">Ouvrir une bande dessinée</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="191"/>
        <source>New instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="210"/>
        <source>Open Folder</source>
        <translation type="unfinished">Ouvrir un dossier</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="212"/>
        <source>Open image folder</source>
        <translation type="unfinished">Ouvrir un dossier d&apos;images</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="217"/>
        <source>Open latest comic</source>
        <translation type="unfinished">Ouvrir la dernière bande dessinée</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="218"/>
        <source>Open the latest comic opened in the previous reading session</source>
        <translation type="unfinished">Ouvrir la dernière bande dessinée ouverte lors de la session de lecture précédente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="230"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="231"/>
        <source>Clear open recent list</source>
        <translation type="unfinished">Vider la liste d&apos;ouverture récente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="234"/>
        <source>Save</source>
        <translation type="unfinished">Sauvegarder</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="236"/>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Save current page</source>
        <translation type="unfinished">Sauvegarder la page actuelle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="241"/>
        <source>Previous Comic</source>
        <translation type="unfinished">Bande dessinée précédente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="243"/>
        <location filename="main_window_viewer.cpp" line="1641"/>
        <location filename="main_window_viewer.cpp" line="1645"/>
        <source>Open previous comic</source>
        <translation type="unfinished">Ouvrir la bande dessiné précédente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="248"/>
        <source>Next Comic</source>
        <translation type="unfinished">Bande dessinée suivante</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="250"/>
        <location filename="main_window_viewer.cpp" line="1640"/>
        <location filename="main_window_viewer.cpp" line="1646"/>
        <source>Open next comic</source>
        <translation type="unfinished">Ouvrir la bande dessinée suivante</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="255"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Précédent</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="258"/>
        <location filename="main_window_viewer.cpp" line="1643"/>
        <location filename="main_window_viewer.cpp" line="1647"/>
        <source>Go to previous page</source>
        <translation type="unfinished">Aller à la page précédente</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="263"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Suivant</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="266"/>
        <location filename="main_window_viewer.cpp" line="1642"/>
        <location filename="main_window_viewer.cpp" line="1648"/>
        <source>Go to next page</source>
        <translation type="unfinished">Aller à la page suivante</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="271"/>
        <source>Fit Height</source>
        <translation type="unfinished">Ajuster la hauteur</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="274"/>
        <source>Fit image to height</source>
        <translation type="unfinished">Ajuster l&apos;image à la hauteur</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="281"/>
        <source>Fit Width</source>
        <translation type="unfinished">Ajuster la largeur</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="284"/>
        <source>Fit image to width</source>
        <translation type="unfinished">Ajuster l&apos;image à la largeur</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="291"/>
        <source>Show full size</source>
        <translation type="unfinished">Plein écran</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="299"/>
        <source>Fit to page</source>
        <translation type="unfinished">Ajuster à la page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="330"/>
        <source>Reset zoom</source>
        <translation type="unfinished">Réinitialiser le zoom</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="335"/>
        <source>Show zoom slider</source>
        <translation type="unfinished">Afficher le curseur de zoom</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="338"/>
        <source>Zoom+</source>
        <translation type="unfinished">Zoom+</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="343"/>
        <source>Zoom-</source>
        <translation type="unfinished">Zoom-</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="348"/>
        <source>Rotate image to the left</source>
        <translation type="unfinished">Rotation à gauche</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="354"/>
        <source>Rotate image to the right</source>
        <translation type="unfinished">Rotation à droite</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="360"/>
        <source>Double page mode</source>
        <translation type="unfinished">Mode double page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="361"/>
        <source>Switch to double page mode</source>
        <translation type="unfinished">Passer en mode double page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="370"/>
        <source>Double page manga mode</source>
        <translation type="unfinished">Mode manga en double page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="371"/>
        <source>Reverse reading order in double page mode</source>
        <translation type="unfinished">Ordre de lecture inversée en mode double page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="380"/>
        <source>Go To</source>
        <translation type="unfinished">Aller à</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="382"/>
        <source>Go to page ...</source>
        <translation type="unfinished">Aller à la page ...</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="387"/>
        <source>Options</source>
        <translation type="unfinished">Options</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="388"/>
        <source>YACReader options</source>
        <translation type="unfinished">Options de YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="395"/>
        <location filename="main_window_viewer.cpp" line="689"/>
        <source>Help</source>
        <translation type="unfinished">Aide</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="396"/>
        <source>Help, About YACReader</source>
        <translation type="unfinished">Aide, à propos de YACReader</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="402"/>
        <source>Magnifying glass</source>
        <translation type="unfinished">Loupe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="403"/>
        <source>Switch Magnifying glass</source>
        <translation type="unfinished">Utiliser la loupe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="410"/>
        <source>Set bookmark</source>
        <translation type="unfinished">Placer un marque-page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="411"/>
        <source>Set a bookmark on the current page</source>
        <translation type="unfinished">Placer un marque-page sur la page actuelle</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="420"/>
        <source>Show bookmarks</source>
        <translation type="unfinished">Voir les marque-pages</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="421"/>
        <source>Show the bookmarks of the current comic</source>
        <translation type="unfinished">Voir les marque-pages de cette bande dessinée</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="427"/>
        <source>Show keyboard shortcuts</source>
        <translation type="unfinished">Voir les raccourcis</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="433"/>
        <source>Show Info</source>
        <translation type="unfinished">Voir les infos</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="439"/>
        <source>Close</source>
        <translation type="unfinished">Fermer</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="445"/>
        <source>Show Dictionary</source>
        <translation type="unfinished">Dictionnaire</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="452"/>
        <source>Show go to flow</source>
        <translation type="unfinished">Afficher le flux</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="458"/>
        <source>Edit shortcuts</source>
        <translation type="unfinished">Modifier les raccourcis</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="481"/>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fichier</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="493"/>
        <location filename="main_window_viewer.cpp" line="644"/>
        <source>Open recent</source>
        <translation type="unfinished">Ouvrir récent</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="633"/>
        <source>File</source>
        <translation type="unfinished">Fichier</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="654"/>
        <source>Edit</source>
        <translation type="unfinished">Editer</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="658"/>
        <source>View</source>
        <translation type="unfinished">Vue</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="674"/>
        <source>Go</source>
        <translation type="unfinished">Aller</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="682"/>
        <source>Window</source>
        <translation type="unfinished">Fenêtre</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Open Comic</source>
        <translation type="unfinished">Ouvrir la bande dessinée</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="783"/>
        <location filename="main_window_viewer.cpp" line="785"/>
        <source>Comic files</source>
        <translation type="unfinished">Bande dessinée</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="876"/>
        <source>Open folder</source>
        <translation type="unfinished">Ouvirir le dossier</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>page_%1.jpg</source>
        <translation type="unfinished">page_%1.jpg</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="932"/>
        <source>Image files (*.jpg)</source>
        <translation type="unfinished">Image(*.jpg)</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1137"/>
        <source>Comics</source>
        <translation type="unfinished">Bandes dessinées</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1147"/>
        <source>Toggle fullscreen mode</source>
        <translation type="unfinished">Basculer en mode plein écran</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1150"/>
        <source>Hide/show toolbar</source>
        <translation type="unfinished">Masquer / afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1153"/>
        <source>General</source>
        <translation type="unfinished">Général</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1172"/>
        <source>Size up magnifying glass</source>
        <translation type="unfinished">Augmenter la taille de la loupe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1175"/>
        <source>Size down magnifying glass</source>
        <translation type="unfinished">Réduire la taille de la loupe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1178"/>
        <source>Zoom in magnifying glass</source>
        <translation type="unfinished">Zoomer</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1181"/>
        <source>Zoom out magnifying glass</source>
        <translation type="unfinished">Dézoomer</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1187"/>
        <source>Magnifiying glass</source>
        <translation type="unfinished">Loupe</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1194"/>
        <source>Toggle between fit to width and fit to height</source>
        <translation type="unfinished">Basculer entre adapter à la largeur et adapter à la hauteur</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1198"/>
        <source>Page adjustement</source>
        <translation type="unfinished">Ajustement de la page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1215"/>
        <source>Autoscroll down</source>
        <translation type="unfinished">Défilement automatique vers le bas</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1218"/>
        <source>Autoscroll up</source>
        <translation type="unfinished">Défilement automatique vers le haut</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1221"/>
        <source>Autoscroll forward, horizontal first</source>
        <translation type="unfinished">Défilement automatique en avant, horizontal</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1225"/>
        <source>Autoscroll backward, horizontal first</source>
        <translation type="unfinished">Défilement automatique en arrière horizontal</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1229"/>
        <source>Autoscroll forward, vertical first</source>
        <translation type="unfinished">Défilement automatique en avant, vertical</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1233"/>
        <source>Autoscroll backward, vertical first</source>
        <translation type="unfinished">Défilement automatique en arrière, verticak</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1237"/>
        <source>Move down</source>
        <translation type="unfinished">Descendre</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1240"/>
        <source>Move up</source>
        <translation type="unfinished">Monter</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1243"/>
        <source>Move left</source>
        <translation type="unfinished">Déplacer à gauche</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1246"/>
        <source>Move right</source>
        <translation type="unfinished">Déplacer à droite</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1249"/>
        <source>Go to the first page</source>
        <translation type="unfinished">Aller à la première page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1252"/>
        <source>Go to the last page</source>
        <translation type="unfinished">Aller à la dernière page</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1255"/>
        <source>Offset double page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1257"/>
        <source>Offset double page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1275"/>
        <source>Reading</source>
        <translation type="unfinished">Lecture</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1320"/>
        <source>There is a new version available</source>
        <translation type="unfinished">Une nouvelle version est disponible</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1321"/>
        <source>Do you want to download the new version?</source>
        <translation type="unfinished">Voulez-vous télécharger la nouvelle version?</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1324"/>
        <source>Remind me in 14 days</source>
        <translation type="unfinished">Rappelez-moi dans 14 jours</translation>
    </message>
    <message>
        <location filename="main_window_viewer.cpp" line="1325"/>
        <source>Not now</source>
        <translation type="unfinished">Pas maintenant</translation>
    </message>
</context>
<context>
    <name>YACReader::WhatsNewDialog</name>
    <message>
        <location filename="../custom_widgets/whats_new_dialog.cpp" line="115"/>
        <source>Close</source>
        <translation type="unfinished">Fermer</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="11"/>
        <source>Restore to default</source>
        <translation>Rétablir les paramètres par défaut</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_edit.cpp" line="28"/>
        <source>Click to overwrite</source>
        <translation>Cliquez pour remplacer</translation>
    </message>
</context>
<context>
    <name>YACReaderFieldPlainTextEdit</name>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="10"/>
        <source>Restore to default</source>
        <translation>Rétablir les paramètres par défaut</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="9"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="19"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="44"/>
        <location filename="../custom_widgets/yacreader_field_plain_text_edit.cpp" line="50"/>
        <source>Click to overwrite</source>
        <translation>Cliquez pour remplacer</translation>
    </message>
</context>
<context>
    <name>YACReaderFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="15"/>
        <source>CoverFlow look</source>
        <translation>Vue CoverFlow</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="13"/>
        <source>How to show covers:</source>
        <translation>Comment voir les couvertures:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="16"/>
        <source>Stripe look</source>
        <translation>Vue alignée</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_flow_config_widget.cpp" line="17"/>
        <source>Overlapped Stripe look</source>
        <translation>Vue superposée</translation>
    </message>
</context>
<context>
    <name>YACReaderGLFlowConfigWidget</name>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="112"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="142"/>
        <source>Light</source>
        <translation>Lumière</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="76"/>
        <source>Show advanced settings</source>
        <translation>Voir les paramètres avancés</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="32"/>
        <source>Roulette look</source>
        <translation>Vue roulette</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="130"/>
        <source>Cover Angle</source>
        <translation>Angle des couvertures</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="23"/>
        <source>Stripe look</source>
        <translation>Vue alignée</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="94"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="124"/>
        <source>Z offset</source>
        <translation>Axe Z</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="118"/>
        <source>Y offset</source>
        <translation>Axe Y</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="106"/>
        <source>Central gap</source>
        <translation>Espace couverture centrale</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="18"/>
        <source>Presets:</source>
        <translation>Réglages:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="26"/>
        <source>Overlapped Stripe look</source>
        <translation>Vue superposée</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="29"/>
        <source>Modern look</source>
        <translation>Vue moderne</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="88"/>
        <source>View angle</source>
        <translation>Angle de vue</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="148"/>
        <source>Max angle</source>
        <translation>Angle Maximum</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="85"/>
        <source>Custom:</source>
        <translation>Personnalisation:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="20"/>
        <source>Classic look</source>
        <translation>Vue classique</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="100"/>
        <source>Cover gap</source>
        <translation>Espace entre les couvertures</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="182"/>
        <source>High Performance</source>
        <translation>Haute performance</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="201"/>
        <source>Performance:</source>
        <translation>Performance:</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="193"/>
        <source>Use VSync (improve the image quality in fullscreen mode, worse performance)</source>
        <translation>Utiliser VSync (Améliore la qualité d&apos;image en mode plein écran, ralentit la performance)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="136"/>
        <source>Visibility</source>
        <translation>Visibilité</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_gl_flow_config_widget.cpp" line="180"/>
        <source>Low Performance</source>
        <translation>Faible performance</translation>
    </message>
</context>
<context>
    <name>YACReaderOptionsDialog</name>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="28"/>
        <source>Save</source>
        <translation>Sauvegarder</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="46"/>
        <source>Use hardware acceleration (restart needed)</source>
        <translation>Utiliser accélération hardware (redémarrage nécessaire)</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="37"/>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <location filename="../custom_widgets/yacreader_options_dialog.cpp" line="34"/>
        <source>Edit shortcuts</source>
        <translation>Modifier les raccourcis</translation>
    </message>
</context>
<context>
    <name>YACReaderSlider</name>
    <message>
        <location filename="width_slider.cpp" line="49"/>
        <source>Reset</source>
        <translation>Remise à zéro</translation>
    </message>
</context>
<context>
    <name>YACReaderTranslator</name>
    <message>
        <location filename="translator.cpp" line="139"/>
        <source>clear</source>
        <translation>effacer</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="216"/>
        <source>Service not available</source>
        <translation>Service non disponible</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="116"/>
        <location filename="translator.cpp" line="207"/>
        <source>Translation</source>
        <translation>Traduction</translation>
    </message>
    <message>
        <location filename="translator.cpp" line="62"/>
        <source>YACReader translator</source>
        <translation>Traducteur YACReader</translation>
    </message>
</context>
</TS>
